@@ -169,7 +169,7 @@ handle_config (struct TAH_RequestHandler *rh,
       GNUNET_JSON_pack_string ("version",
                                AUDITOR_PROTOCOL_VERSION),
       GNUNET_JSON_pack_string ("implementation",
-                               "urn:net:taler:specs:auditor:c-reference"),
+                               "urn:net:taler:specs:taler-auditor:c-reference"),
       GNUNET_JSON_pack_string ("currency",
                                TAH_currency),
       GNUNET_JSON_pack_data_auto ("auditor_public_key",
