@@ -52,6 +52,14 @@
                                                       15)
 
 
+/**
+ * Run in test mode. Exit when idle instead of
+ * going to sleep and waiting for more work.
+ *
+ * FIXME: not yet implemented!
+ */
+static int test_mode;
+
 struct TALER_AUDITORDB_WireAccountProgressPoint
 {
   uint64_t last_reserve_in_serial_id;
@@ -2894,11 +2902,10 @@ main (int argc,
                                "ignore-not-found",
                                "continue, even if the bank account of the exchange was not found",
                                &ignore_account_404),
-    GNUNET_GETOPT_option_base32_auto ('m',
-                                      "exchange-key",
-                                      "KEY",
-                                      "public key of the exchange (Crockford base32 encoded)",
-                                      &TALER_ARL_master_pub),
+    GNUNET_GETOPT_option_flag ('t',
+                               "test",
+                               "run in test mode and exit when idle",
+                               &test_mode),
     GNUNET_GETOPT_option_timetravel ('T',
                                      "timetravel"),
     GNUNET_GETOPT_OPTION_END
