@@ -32,11 +32,6 @@
 struct DepositConfirmationContext
 {
 
-  /**
-   * Master public key that is being used.
-   */
-  const struct TALER_MasterPublicKeyP *master_pub;
-
   /**
    * Function to call for each deposit confirmation.
    */
@@ -79,9 +74,7 @@ deposit_confirmation_cb (void *cls,
   for (unsigned int i = 0; i < num_results; i++)
   {
     uint64_t serial_id;
-    struct TALER_AUDITORDB_DepositConfirmation dc = {
-      .master_public_key = *dcc->master_pub
-    };
+    struct TALER_AUDITORDB_DepositConfirmation dc = { 0};
     struct TALER_CoinSpendPublicKeyP *coin_pubs = NULL;
     struct TALER_CoinSpendSignatureP *coin_sigs = NULL;
     size_t num_pubs = 0;
@@ -104,7 +97,7 @@ deposit_confirmation_cb (void *cls,
       TALER_PQ_RESULT_SPEC_AMOUNT ("total_without_fee",
                                    &dc.total_without_fee),
       GNUNET_PQ_result_spec_auto_array_from_type (pg->conn,
-                                                  "coin_pub",
+                                                  "coin_pubs",
                                                   &num_pubs,
                                                   coin_pubs),
       GNUNET_PQ_result_spec_auto_array_from_type (pg->conn,
@@ -156,19 +149,18 @@ deposit_confirmation_cb (void *cls,
 enum GNUNET_DB_QueryStatus
 TAH_PG_get_deposit_confirmations (
   void *cls,
-  const struct TALER_MasterPublicKeyP *master_public_key,
   uint64_t start_id,
+  bool return_suppressed,
   TALER_AUDITORDB_DepositConfirmationCallback cb,
   void *cb_cls)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
-    GNUNET_PQ_query_param_auto_from_type (master_public_key),
     GNUNET_PQ_query_param_uint64 (&start_id),
+    GNUNET_PQ_query_param_bool (return_suppressed),
     GNUNET_PQ_query_param_end
   };
   struct DepositConfirmationContext dcc = {
-    .master_pub = master_public_key,
     .cb = cb,
     .cb_cls = cb_cls,
     .pg = pg
@@ -178,7 +170,7 @@ TAH_PG_get_deposit_confirmations (
   PREPARE (pg,
            "auditor_deposit_confirmation_select",
            "SELECT"
-           " serial_id"
+           " deposit_confirmation_serial_id"
            ",h_contract_terms"
            ",h_policy"
            ",h_wire"
@@ -191,10 +183,10 @@ TAH_PG_get_deposit_confirmations (
            ",merchant_pub"
            ",exchange_sig"
            ",exchange_pub"
-           ",master_sig"                  /* master_sig could be normalized... */
-           " FROM deposit_confirmations"
-           " WHERE master_pub=$1"
-           " AND serial_id>$2");
+           ",master_sig"
+           " FROM auditor_deposit_confirmations"
+           " WHERE deposit_confirmation_serial_id>$1"
+           " AND ($2 OR NOT suppressed);");
   qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
                                              "auditor_deposit_confirmation_select",
                                              params,
