@@ -148,6 +148,7 @@ TALER_FAKEBANK_twg_get_debit_history_ (
            (0 < hc->ha.delta))
       {
         acc_payto_uri = hc->acc->payto_uri;
+        in_shutdown = h->in_shutdown;
         GNUNET_assert (0 ==
                        pthread_mutex_unlock (&h->big_lock));
         if (overflow)
@@ -162,6 +163,7 @@ TALER_FAKEBANK_twg_get_debit_history_ (
       if (h->in_shutdown)
       {
         acc_payto_uri = hc->acc->payto_uri;
+        in_shutdown = h->in_shutdown;
         GNUNET_assert (0 ==
                        pthread_mutex_unlock (&h->big_lock));
         goto finish;
@@ -323,7 +325,12 @@ TALER_FAKEBANK_twg_get_credit_history_ (
     *con_cls = cc;
     hc = GNUNET_new (struct HistoryContext);
     cc->ctx = hc;
-
+    hc->history = json_array ();
+    if (NULL == hc->history)
+    {
+      GNUNET_break (0);
+      return MHD_NO;
+    }
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Handling /history/incoming connection %p\n",
                 connection);
@@ -335,6 +342,7 @@ TALER_FAKEBANK_twg_get_credit_history_ (
       GNUNET_break_op (0);
       return (GNUNET_SYSERR == ret) ? MHD_NO : MHD_YES;
     }
+    hc->timeout = GNUNET_TIME_relative_to_absolute (hc->ha.lp_timeout);
     GNUNET_assert (0 ==
                    pthread_mutex_lock (&h->big_lock));
     if (UINT64_MAX == hc->ha.start_idx)
@@ -351,15 +359,6 @@ TALER_FAKEBANK_twg_get_credit_history_ (
                                          TALER_EC_BANK_UNKNOWN_ACCOUNT,
                                          account);
     }
-    hc->history = json_array ();
-    if (NULL == hc->history)
-    {
-      GNUNET_break (0);
-      GNUNET_assert (0 ==
-                     pthread_mutex_unlock (&h->big_lock));
-      return MHD_NO;
-    }
-    hc->timeout = GNUNET_TIME_relative_to_absolute (hc->ha.lp_timeout);
   }
   else
   {
@@ -398,6 +397,7 @@ TALER_FAKEBANK_twg_get_credit_history_ (
     if ( (NULL == t) ||
          overflow)
     {
+      in_shutdown = h->in_shutdown;
       /* FIXME: these conditions are unclear to me. */
       if (GNUNET_TIME_relative_is_zero (hc->ha.lp_timeout) &&
           (0 < hc->ha.delta))
@@ -412,7 +412,7 @@ TALER_FAKEBANK_twg_get_credit_history_ (
             NULL);
         goto finish;
       }
-      if (h->in_shutdown)
+      if (in_shutdown)
       {
         acc_payto_uri = hc->acc->payto_uri;
         GNUNET_assert (0 ==
