@@ -110,13 +110,12 @@ extern struct TALER_Amount TEH_stefan_log;
 /**
  * Linear STEFAN parameter.
  */
-extern struct TALER_Amount TEH_stefan_lin;
+extern float TEH_stefan_lin;
 
 /**
- * Default number of fractional digits to render
- * amounts with.
+ * Default ways how to render #TEH_currency amounts.
  */
-extern unsigned int TEH_currency_fraction_digits;
+extern const struct TALER_CurrencySpecification *TEH_cspec;
 
 /**
  * Our currency.
@@ -199,6 +198,11 @@ struct TEH_RequestContext
    */
   struct MHD_Connection *connection;
 
+  /**
+   * JSON root of uploaded data (or NULL, if none).
+   */
+  json_t *root;
+
   /**
    * @e rh-specific cleanup routine. Function called
    * upon completion of the request that should
