@@ -406,29 +406,33 @@ kyc_check (void *cls,
                                            "insert_kyc_requirement_process");
     return GNUNET_DB_STATUS_HARD_ERROR;
   }
-  if (qs > 0)
+  if ( (qs > 0) &&
+       (NULL != redirect_url) )
   {
     kyp->kyc_url = redirect_url;
     return qs;
   }
-  qs = TEH_plugin->insert_kyc_requirement_process (
-    TEH_plugin->cls,
-    &h_payto,
-    kyp->section_name,
-    NULL,
-    NULL,
-    &kyp->process_row);
-
-  if (qs < 0)
+  if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
   {
-    if (GNUNET_DB_STATUS_SOFT_ERROR == qs)
-      return qs;
-    GNUNET_break (0);
-    *mhd_ret = TALER_MHD_reply_with_error (connection,
-                                           MHD_HTTP_INTERNAL_SERVER_ERROR,
-                                           TALER_EC_GENERIC_DB_STORE_FAILED,
-                                           "insert_kyc_requirement_process");
-    return GNUNET_DB_STATUS_HARD_ERROR;
+    /* set up new requirement process */
+    qs = TEH_plugin->insert_kyc_requirement_process (
+      TEH_plugin->cls,
+      &h_payto,
+      kyp->section_name,
+      NULL,
+      NULL,
+      &kyp->process_row);
+    if (qs < 0)
+    {
+      if (GNUNET_DB_STATUS_SOFT_ERROR == qs)
+        return qs;
+      GNUNET_break (0);
+      *mhd_ret = TALER_MHD_reply_with_error (connection,
+                                             MHD_HTTP_INTERNAL_SERVER_ERROR,
+                                             TALER_EC_GENERIC_DB_STORE_FAILED,
+                                             "insert_kyc_requirement_process");
+      return GNUNET_DB_STATUS_HARD_ERROR;
+    }
   }
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Initiating KYC check with logic %s\n",
