@@ -81,6 +81,7 @@
 #include "pg_get_drain_profit.h"
 #include "pg_get_purse_deposit.h"
 #include "pg_insert_contract.h"
+#include "pg_insert_kyc_failure.h"
 #include "pg_select_contract.h"
 #include "pg_select_purse_merge.h"
 #include "pg_select_contract_by_purse.h"
@@ -160,6 +161,7 @@
 #include "pg_start_deferred_wire_out.h"
 #include "pg_store_wire_transfer_out.h"
 #include "pg_gc.h"
+#include "pg_inject_auditor_triggers.h"
 #include "pg_select_coin_deposits_above_serial_id.h"
 #include "pg_select_purse_decisions_above_serial_id.h"
 #include "pg_select_purse_deposits_by_purse.h"
@@ -271,6 +273,8 @@ TEH_PG_internal_setup (struct PostgresClosure *pg)
       GNUNET_PQ_make_try_execute ("SET enable_sort=OFF;"),
       GNUNET_PQ_make_try_execute ("SET enable_seqscan=OFF;"),
       GNUNET_PQ_make_try_execute ("SET search_path TO exchange;"),
+      /* Mergejoin causes issues, see Postgres #18380 */
+      GNUNET_PQ_make_try_execute ("SET enable_mergejoin=OFF;"),
       GNUNET_PQ_EXECUTE_STATEMENT_END
     };
 #else
@@ -279,7 +283,8 @@ TEH_PG_internal_setup (struct PostgresClosure *pg)
         "SET SESSION CHARACTERISTICS AS TRANSACTION ISOLATION LEVEL SERIALIZABLE;"),
       GNUNET_PQ_make_try_execute ("SET enable_sort=OFF;"),
       GNUNET_PQ_make_try_execute ("SET enable_seqscan=OFF;"),
-      GNUNET_PQ_make_try_execute ("SET autocommit=OFF;"),
+      /* Mergejoin causes issues, see Postgres #18380 */
+      GNUNET_PQ_make_try_execute ("SET enable_mergejoin=OFF;"),
       GNUNET_PQ_make_try_execute ("SET search_path TO exchange;"),
       GNUNET_PQ_EXECUTE_STATEMENT_END
     };
@@ -743,6 +748,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_begin_shard;
   plugin->abort_shard
     = &TEH_PG_abort_shard;
+  plugin->insert_kyc_failure
+    = &TEH_PG_insert_kyc_failure;
   plugin->complete_shard
     = &TEH_PG_complete_shard;
   plugin->release_revolving_shard
@@ -784,6 +791,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
 
   plugin->batch_ensure_coin_known
     = &TEH_PG_batch_ensure_coin_known;
+  plugin->inject_auditor_triggers
+    = &TEH_PG_inject_auditor_triggers;
 
   return plugin;
 }
