@@ -45,7 +45,8 @@ static int result;
  * Initializes @a ptr with random data.
  */
 #define RND_BLK(ptr)                                                    \
-  GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK, ptr, sizeof (*ptr))
+  GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK, ptr, \
+                              sizeof (*ptr))
 
 /**
  * Initializes @a ptr with zeros.
@@ -278,7 +279,7 @@ create_denom_key_pair (unsigned int size,
   GNUNET_assert (GNUNET_OK ==
                  TALER_denom_priv_create (&dkp->priv,
                                           &dkp->pub,
-                                          TALER_DENOMINATION_RSA,
+                                          GNUNET_CRYPTO_BSA_RSA,
                                           size));
   /* Using memset() as fields like master key and signature
      are not properly initialized for this test. */
@@ -1092,9 +1093,9 @@ recoup_cb (void *cls,
            const struct TALER_CoinPublicInfo *coin,
            const struct TALER_DenominationPublicKey *denom_pub,
            const struct TALER_CoinSpendSignatureP *coin_sig,
-           const union TALER_DenominationBlindingKeyP *coin_blind)
+           const union GNUNET_CRYPTO_BlindingSecretP *coin_blind)
 {
-  const union TALER_DenominationBlindingKeyP *cb = cls;
+  const union GNUNET_CRYPTO_BlindingSecretP *cb = cls;
 
   (void) rowid;
   (void) timestamp;
@@ -1177,7 +1178,7 @@ run (void *cls)
   struct GNUNET_CONFIGURATION_Handle *cfg = cls;
   struct TALER_CoinSpendSignatureP coin_sig;
   struct GNUNET_TIME_Timestamp deadline;
-  union TALER_DenominationBlindingKeyP coin_blind;
+  union GNUNET_CRYPTO_BlindingSecretP coin_blind;
   struct TALER_ReservePublicKeyP reserve_pub;
   struct TALER_ReservePublicKeyP reserve_pub2;
   struct TALER_ReservePublicKeyP reserve_pub3;
@@ -1212,12 +1213,9 @@ run (void *cls)
   uint64_t reserve_out_serial_id;
   uint64_t melt_serial_id;
   struct TALER_PlanchetMasterSecretP ps;
-  union TALER_DenominationBlindingKeyP bks;
-  struct TALER_ExchangeWithdrawValues alg_values = {
-    /* RSA is simpler, and for the DB there is no real difference between
-       CS and RSA, just one should be used, so we use RSA */
-    .cipher = TALER_DENOMINATION_RSA
-  };
+  union GNUNET_CRYPTO_BlindingSecretP bks;
+  const struct TALER_ExchangeWithdrawValues *alg_values
+    = TALER_denom_ewv_rsa_singleton ();
 
   memset (&deposit,
           0,
@@ -1359,7 +1357,7 @@ run (void *cls)
   RND_BLK (&cbc.reserve_sig);
   RND_BLK (&ps);
   TALER_planchet_blinding_secret_create (&ps,
-                                         &alg_values,
+                                         alg_values,
                                          &bks);
   {
     struct TALER_PlanchetDetail pd;
@@ -1380,15 +1378,15 @@ run (void *cls)
       GNUNET_assert (GNUNET_OK ==
                      TALER_denom_blind (&dkp->pub,
                                         &bks,
+                                        NULL,
                                         p_ah[i],
                                         &coin_pub,
-                                        &alg_values,
+                                        alg_values,
                                         &c_hash,
                                         &pd.blinded_planchet));
-      GNUNET_assert (GNUNET_OK ==
-                     TALER_coin_ev_hash (&pd.blinded_planchet,
-                                         &cbc.denom_pub_hash,
-                                         &cbc.h_coin_envelope));
+      TALER_coin_ev_hash (&pd.blinded_planchet,
+                          &cbc.denom_pub_hash,
+                          &cbc.h_coin_envelope);
       if (i != 0)
         TALER_blinded_denom_sig_free (&cbc.sig);
       GNUNET_assert (
@@ -1410,26 +1408,39 @@ run (void *cls)
 
   {
     bool found;
-    bool nonce_ok;
+    bool nonce_reuse;
     bool balance_ok;
     bool age_ok;
+    bool conflict;
+    bool denom_unknown;
     uint16_t maximum_age;
     uint64_t ruuid;
+    struct TALER_Amount reserve_balance;
 
     FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
-            plugin->do_withdraw (plugin->cls,
-                                 NULL,
-                                 &cbc,
-                                 now,
-                                 false,
-                                 &found,
-                                 &balance_ok,
-                                 &nonce_ok,
-                                 &age_ok,
-                                 &maximum_age,
-                                 &ruuid));
+            plugin->do_batch_withdraw (plugin->cls,
+                                       now,
+                                       &reserve_pub,
+                                       &value,
+                                       true,
+                                       &found,
+                                       &balance_ok,
+                                       &reserve_balance,
+                                       &age_ok,
+                                       &maximum_age,
+                                       &ruuid));
+    FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
+            plugin->do_batch_withdraw_insert (plugin->cls,
+                                              NULL,
+                                              &cbc,
+                                              now,
+                                              ruuid,
+                                              &denom_unknown,
+                                              &conflict,
+                                              &nonce_reuse));
     GNUNET_assert (found);
-    GNUNET_assert (nonce_ok);
+    GNUNET_assert (! nonce_reuse);
+    GNUNET_assert (! denom_unknown);
     GNUNET_assert (balance_ok);
   }
 
@@ -1470,7 +1481,7 @@ run (void *cls)
                                             &cbc2.sig,
                                             &bks,
                                             &c_hash,
-                                            &alg_values,
+                                            alg_values,
                                             &dkp->pub));
     FAILIF (GNUNET_OK !=
             TALER_denom_pub_verify (&dkp->pub,
@@ -1489,7 +1500,7 @@ run (void *cls)
                                           &cbc.sig,
                                           &bks,
                                           &c_hash,
-                                          &alg_values,
+                                          alg_values,
                                           &dkp->pub));
   deadline = GNUNET_TIME_timestamp_get ();
   {
@@ -1642,7 +1653,8 @@ run (void *cls)
     {
       struct TALER_EXCHANGEDB_RefreshRevealedCoin *ccoin;
       struct GNUNET_TIME_Timestamp now;
-      struct TALER_BlindedRsaPlanchet *rp;
+      struct GNUNET_CRYPTO_BlindedMessage *rp;
+      struct GNUNET_CRYPTO_RsaBlindedMessage *rsa;
       struct TALER_BlindedPlanchet *bp;
 
       now = GNUNET_TIME_timestamp_get ();
@@ -1654,18 +1666,22 @@ run (void *cls)
       new_denom_pubs[cnt] = new_dkp[cnt]->pub;
       ccoin = &revealed_coins[cnt];
       bp = &ccoin->blinded_planchet;
-      bp->cipher = TALER_DENOMINATION_RSA;
-      rp = &bp->details.rsa_blinded_planchet;
-      rp->blinded_msg_size = 1 + (size_t) GNUNET_CRYPTO_random_u64 (
+      rp = GNUNET_new (struct GNUNET_CRYPTO_BlindedMessage);
+      bp->blinded_message = rp;
+      rp->cipher = GNUNET_CRYPTO_BSA_RSA;
+      rp->rc = 1;
+      rsa = &rp->details.rsa_blinded_message;
+      rsa->blinded_msg_size = 1 + (size_t) GNUNET_CRYPTO_random_u64 (
         GNUNET_CRYPTO_QUALITY_WEAK,
         (RSA_KEY_SIZE / 8) - 1);
-      rp->blinded_msg = GNUNET_malloc (rp->blinded_msg_size);
+      rsa->blinded_msg = GNUNET_malloc (rsa->blinded_msg_size);
       GNUNET_CRYPTO_random_block (GNUNET_CRYPTO_QUALITY_WEAK,
-                                  rp->blinded_msg,
-                                  rp->blinded_msg_size);
+                                  rsa->blinded_msg,
+                                  rsa->blinded_msg_size);
       TALER_denom_pub_hash (&new_dkp[cnt]->pub,
                             &ccoin->h_denom_pub);
-      ccoin->exchange_vals = alg_values;
+      TALER_denom_ewv_copy (&ccoin->exchange_vals,
+                            alg_values);
       TALER_coin_ev_hash (bp,
                           &ccoin->h_denom_pub,
                           &ccoin->coin_envelope_hash);
@@ -1724,12 +1740,16 @@ run (void *cls)
       struct TALER_EXCHANGEDB_TransactionList *tl;
       enum GNUNET_DB_QueryStatus qs;
       uint64_t etag;
+      struct TALER_Amount balance;
+      struct TALER_DenominationHashP h_denom_pub;
 
       qs = plugin->get_coin_transactions (plugin->cls,
                                           &refresh.coin.coin_pub,
                                           0,
                                           0,
                                           &etag,
+                                          &balance,
+                                          &h_denom_pub,
                                           &tl);
       FAILIF (0 >= qs);
       FAILIF (NULL == tl);
@@ -1742,7 +1762,7 @@ run (void *cls)
   {
     struct GNUNET_TIME_Timestamp recoup_timestamp
       = GNUNET_TIME_timestamp_get ();
-    union TALER_DenominationBlindingKeyP coin_bks;
+    union GNUNET_CRYPTO_BlindingSecretP coin_bks;
     uint64_t new_known_coin_id;
     struct TALER_CoinPublicInfo new_coin;
     struct TALER_DenominationHashP dph;
@@ -1985,12 +2005,16 @@ run (void *cls)
   FAILIF (1 != auditor_row_cnt);
   {
     uint64_t etag = 0;
+    struct TALER_Amount balance;
+    struct TALER_DenominationHashP h_denom_pub;
 
     qs = plugin->get_coin_transactions (plugin->cls,
                                         &refund.coin.coin_pub,
                                         0,
                                         0,
                                         &etag,
+                                        &balance,
+                                        &h_denom_pub,
                                         &tl);
   }
   FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT != qs);
@@ -2108,7 +2132,7 @@ run (void *cls)
                                           &cbc.sig,
                                           &bks,
                                           &c_hash,
-                                          &alg_values,
+                                          alg_values,
                                           &dkp->pub));
   RND_BLK (&deposit.csig);
   RND_BLK (&bd.merchant_pub);
@@ -2452,6 +2476,7 @@ main (int argc,
   GNUNET_log_setup (argv[0],
                     "INFO",
                     NULL);
+  TALER_OS_init ();
   plugin_name++;
   (void) GNUNET_asprintf (&testname,
                           "test-exchange-db-%s",
