@@ -271,6 +271,12 @@
 #define TALER_SIGNATURE_MERCHANT_WIRE_DETAILS 1107
 
 
+/**
+ * Signature where the merchant issues a token by blindly signing it. Signed with the token issue private key.
+ */
+#define TALER_SIGNATURE_MERCHANT_TOKEN_ISSUE 1108
+
+
 /**
  * Signature where the reserve key confirms a withdraw request. Signed with the reserve private key.
  */
@@ -403,6 +409,12 @@
 #define TALER_SIGNATURE_WALLET_RESERVE_AGE_WITHDRAW 1221
 
 
+/**
+ * Signature where the token use key confirms the usage of a token on a pay request. Signed with the token use private key.
+ */
+#define TALER_SIGNATURE_WALLET_TOKEN_USE 1222
+
+
 /**
  * Signature on a denomination key announcement.
  */
