@@ -990,9 +990,9 @@ proceed_with_handler (struct TEKT_RequestContext *rc,
 
     /* Parse command-line arguments */
     /* make a copy of 'url' because 'strtok_r()' will modify */
-    memcpy (d,
-            url,
-            ulen);
+    GNUNET_memcpy (d,
+                   url,
+                   ulen);
     i = 0;
     args[i++] = strtok_r (d, "/", &sp);
     while ( (NULL != args[i - 1]) &&
