@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2014--2020 Taler Systems SA
+  Copyright (C) 2014--2024 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -245,6 +245,73 @@ TALER_MHD_parse_request_arg_number (struct MHD_Connection *connection,
 }
 
 
+enum GNUNET_GenericReturnValue
+TALER_MHD_parse_request_arg_snumber (struct MHD_Connection *connection,
+                                     const char *name,
+                                     int64_t *val)
+{
+  const char *ts;
+  char dummy;
+  long long num;
+
+  ts = MHD_lookup_connection_value (connection,
+                                    MHD_GET_ARGUMENT_KIND,
+                                    name);
+  if (NULL == ts)
+    return GNUNET_OK;
+  if (1 !=
+      sscanf (ts,
+              "%lld%c",
+              &num,
+              &dummy))
+  {
+    MHD_RESULT mret;
+
+    GNUNET_break_op (0);
+    mret = TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       name);
+    return (MHD_YES == mret)
+      ? GNUNET_NO
+      : GNUNET_SYSERR;
+  }
+  *val = (int64_t) num;
+  return GNUNET_OK;
+}
+
+
+enum GNUNET_GenericReturnValue
+TALER_MHD_parse_request_arg_amount (struct MHD_Connection *connection,
+                                    const char *name,
+                                    struct TALER_Amount *val)
+{
+  const char *ts;
+
+  ts = MHD_lookup_connection_value (connection,
+                                    MHD_GET_ARGUMENT_KIND,
+                                    name);
+  if (NULL == ts)
+    return GNUNET_OK;
+  if (GNUNET_OK !=
+      TALER_string_to_amount (ts,
+                              val))
+  {
+    MHD_RESULT mret;
+
+    GNUNET_break_op (0);
+    mret = TALER_MHD_reply_with_error (connection,
+                                       MHD_HTTP_BAD_REQUEST,
+                                       TALER_EC_GENERIC_PARAMETER_MALFORMED,
+                                       name);
+    return (MHD_YES == mret)
+      ? GNUNET_NO
+      : GNUNET_SYSERR;
+  }
+  return GNUNET_OK;
+}
+
+
 enum GNUNET_GenericReturnValue
 TALER_MHD_parse_json_data (struct MHD_Connection *connection,
                            const json_t *root,
@@ -441,4 +508,66 @@ TALER_MHD_check_content_length_ (struct MHD_Connection *connection,
 }
 
 
+int
+TALER_MHD_check_accept (struct MHD_Connection *connection,
+                        const char *header,
+                        ...)
+{
+  bool ret = false;
+  const char *accept;
+  char *a;
+  char *saveptr;
+
+  accept = MHD_lookup_connection_value (connection,
+                                        MHD_HEADER_KIND,
+                                        header);
+  if (NULL == accept)
+    return -2; /* no Accept header set */
+
+  a = GNUNET_strdup (accept);
+  for (char *t = strtok_r (a, ",", &saveptr);
+       NULL != t;
+       t = strtok_r (NULL, ",", &saveptr))
+  {
+    char *end;
+
+    /* skip leading whitespace */
+    while (isspace ((unsigned char) t[0]))
+      t++;
+    /* trim of ';q=' parameter and everything after space */
+    /* FIXME: eventually, we might want to parse the "q=$FLOAT"
+       part after the ';' and figure out which one is the
+       best/preferred match instead of returning a boolean... */
+    end = strchr (t, ';');
+    if (NULL != end)
+      *end = '\0';
+    end = strchr (t, ' ');
+    if (NULL != end)
+      *end = '\0';
+    {
+      va_list ap;
+      int off = 0;
+      const char *val;
+
+      va_start (ap,
+                header);
+      while (NULL != (val = va_arg (ap,
+                                    const char *)))
+      {
+        if (0 == strcasecmp (val,
+                             t))
+        {
+          ret = off;
+          break;
+        }
+        off++;
+      }
+      va_end (ap);
+    }
+  }
+  GNUNET_free (a);
+  return ret;
+}
+
+
 /* end of mhd_parsing.c */
