@@ -55,7 +55,7 @@ static struct TALER_TESTING_Credentials cred;
 
 /**
  * Some tests behave differently when using CS as we cannot
- * re-use the coin private key for different denominations
+ * reuse the coin private key for different denominations
  * due to the derivation of it with the /csr values. Hence
  * some tests behave differently in CS mode, hence this
  * flag.
@@ -186,7 +186,12 @@ run (void *cls,
                                GNUNET_TIME_UNIT_ZERO,
                                "EUR:5",
                                MHD_HTTP_OK),
-    TALER_TESTING_cmd_deposit_replay ("deposit-simple-replay",
+    TALER_TESTING_cmd_deposit_replay ("deposit-simple-replay-1",
+                                      "deposit-simple",
+                                      MHD_HTTP_OK),
+    TALER_TESTING_cmd_sleep ("sleep-before-deposit-replay",
+                             1),
+    TALER_TESTING_cmd_deposit_replay ("deposit-simple-replay-2",
                                       "deposit-simple",
                                       MHD_HTTP_OK),
     /* This creates a conflict, as we have the same coin public key (reuse!),
@@ -405,6 +410,14 @@ run (void *cls,
     TALER_TESTING_cmd_deposit_replay ("deposit-simple-replay-age",
                                       "deposit-simple-age",
                                       MHD_HTTP_OK),
+    TALER_TESTING_cmd_deposit_replay ("deposit-simple-replay-age-1",
+                                      "deposit-simple-age",
+                                      MHD_HTTP_OK),
+    TALER_TESTING_cmd_sleep ("sleep-before-age-deposit-replay",
+                             1),
+    TALER_TESTING_cmd_deposit_replay ("deposit-simple-replay-age-2",
+                                      "deposit-simple-age",
+                                      MHD_HTTP_OK),
     TALER_TESTING_cmd_end ()
   };
 
@@ -1169,6 +1182,10 @@ run (void *cls,
                                      "batch-withdraw-coin-1#1",
                                      "EUR:1",
                                      NULL),
+    TALER_TESTING_cmd_coin_history ("coin-history-batch-1",
+                                    "batch-withdraw-coin-1#0",
+                                    "EUR:0.0",
+                                    MHD_HTTP_OK),
     TALER_TESTING_cmd_end ()
   };
 
